@@ -81,14 +81,11 @@ import uuid
 
 
 __all__ = ['bounds', 'listlayers', 'open', 'prop_type', 'prop_width']
-__version__ = "1.7.1"
+__version__ = "1.7.9"
 __gdal_version__ = get_gdal_release_name().decode('utf-8')
 
-log = logging.getLogger('Fiona')
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
-log.addHandler(NullHandler())
+log = logging.getLogger(__name__)
+
 
 def open(
         path,
@@ -238,6 +235,7 @@ def listlayers(path, vfs=None):
     with drivers():
         return _listlayers(vsi_path(path, vsi, archive))
 
+
 def parse_paths(path, vfs=None):
     archive = vsi = None
     if vfs:
@@ -250,6 +248,7 @@ def parse_paths(path, vfs=None):
         vsi = parts.pop() if parts else None
     return path, vsi, archive
 
+
 def prop_width(val):
     """Returns the width of a str type property.
 
@@ -264,6 +263,7 @@ def prop_width(val):
         return int((val.split(":")[1:] or ["80"])[0])
     return None
 
+
 def prop_type(text):
     """Returns a schema property's proper Python type.
 
